%define anolis_release 1

# Release 2023.1
%global commit          d0b02222f33e1e5e1f521e4e4e1cbfa7fe2cf540
%global shortcommit     %(c=%{commit}; echo ${c:0:7})
%global snapshotdate    20230116

# Glslang revision from packaged version
%global glslang_version ca8d07d0bc1c6390b83915700439fa7719de6a2a

Name:           shaderc
Version:        2023.1
Release:        %{anolis_release}%{?dist}
Summary:        A collection of tools, libraries, and tests for Vulkan shader compilation

License:        Apache-2.0
URL:            https://github.com/google/shaderc
Source0:        %url/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
# Patch to unbundle 3rd party code
Patch1:         0001-Drop-third-party-code-in-CMakeLists.txt.patch
Patch2:         glslang_linker_flags.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja-build
BuildRequires:  python3-devel
BuildRequires:  glslang-devel
BuildRequires:  spirv-headers-devel
BuildRequires:  spirv-tools
BuildRequires:  spirv-tools-devel >= %{version}

%description
A collection of tools, libraries and tests for shader compilation.

Shaderc aims to to provide:
 - a command line compiler with GCC- and Clang-like usage, for better
   integration with build systems
 - an API where functionality can be added without breaking existing clients
 - an API supporting standard concurrency patterns across multiple
   operating systems
 - increased functionality such as file #include support

%package    -n  glslc
Summary:        A command line compiler for GLSL/HLSL to SPIR-V
Requires:       spirv-tools-libs = %{installed_version_of spirv-tools-libs}

%description -n glslc
A command line compiler for GLSL/HLSL to SPIR-V.

%package    -n  glslc-doc
Summary:        Documentation files for glslc
Requires:       glslc = %{version}-%{release}
Buildarch:      noarch

%description -n glslc-doc
The glslc-doc package contains documentation files for glslc.

%package    -n  libshaderc
Summary:        A library for compiling shader strings into SPIR-V
Requires:       spirv-tools-libs = %{installed_version_of spirv-tools-libs}

%description -n libshaderc
A library for compiling shader strings into SPIR-V.

%package doc
Requires:       libshaderc = %{version}-%{release}
Summary:        Documentation files for libshaderc
Buildarch:      noarch

%description    doc
The libshaderc-doc package contains documentation files for libshaderc.


%package -n     libshaderc-devel
Summary:        Development files for libshaderc
Requires:       libshaderc = %{version}-%{release}

%description -n libshaderc-devel
A library for compiling shader strings into SPIR-V.

Development files for libshaderc.

%package -n     libshaderc-static
Summary:        A library for compiling shader strings into SPIR-V (static libraries)
Requires:	libshaderc-devel = %{version}-%{release}

%description -n libshaderc-static
A library for compiling shader strings into SPIR-V.

Static libraries for libshaderc.

%prep
%autosetup -p1 -n %{name}-%{commit}

rm -rf third_party

# Stolen from Gentoo
# Create build-version.inc since we want to use our packaged
# SPIRV-Tools and glslang
sed -i -e '/build-version/d' glslc/CMakeLists.txt
echo \"shaderc $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' CHANGES)\" \
        > glslc/src/build-version.inc
echo \"spirv-tools $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' /usr/share/doc/spirv-tools/CHANGES)\" \
        >> glslc/src/build-version.inc
echo \"glslang %{glslang_version}\" >> glslc/src/build-version.inc

# Point to correct include
sed -i 's|SPIRV/GlslangToSpv.h|glslang/SPIRV/GlslangToSpv.h|' libshaderc_util/src/compiler.cc

%build
# We disable the tests because they don't work with our unbundling of 3rd party.
# See https://github.com/google/shaderc/issues/470
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_SKIP_RPATH=True \
        -DSHADERC_SKIP_TESTS=True \
        -DPYTHON_EXE=%{__python3} \
        -GNinja
%cmake_build

%install
%cmake_install

%generate_compatibility_deps

%check
%ctest

%files -n glslc
%license LICENSE
%dir %{abidir}
%{_bindir}/glslc
%{abidir}/glslc-option.list

%files -n glslc-doc
%doc glslc/README.asciidoc

%files -n libshaderc
%license LICENSE
%dir %{abidir}
%{_libdir}/libshaderc_shared.so.1*
%{abidir}/libshaderc_shared.dump

%files doc
%doc AUTHORS CHANGES CONTRIBUTORS README.md

%files -n libshaderc-devel
%{_includedir}/%{name}
%{_libdir}/libshaderc_shared.so
%{_libdir}/pkgconfig/shaderc.pc

%files -n libshaderc-static
%license LICENSE
%{_libdir}/libshaderc.a
%{_libdir}/libshaderc_combined.a
%{_libdir}/pkgconfig/shaderc_static.pc
%{_libdir}/pkgconfig/shaderc_combined.pc

%changelog
* Tue Mar 07 2023 Funda Wang <fundawang@yeah.net> - 2023.1-1
- Import package for anolis 23
